package constant

// UserStatus 用户状态
type UserStatus string

const (
	UserStatusActive   UserStatus = "NORMAL"  // 用户状态正常
	UserStatusDisabled UserStatus = "DISABLE" // 已禁用用户
)

// 状态对应的描述
var userStatusMap = map[UserStatus]string{
	UserStatusActive:   "正常",
	UserStatusDisabled: "已禁用",
}

// 处理为看得懂的状态
func (s UserStatus) String() string {
	if str, ok := userStatusMap[s]; ok {
		return str
	}
	return string(s)
}

// =====================================================================================================================

// UserIdentity 用户身份
type UserIdentity string

const (
	UserIdentityAdmin UserIdentity = "admin" // 管理员
	UserIdentityUser  UserIdentity = "user"  // 普通用户
)

// String implements the Stringer interface.
func (t UserIdentity) String() string {
	return string(t)
}
